@@ -4,7 +4,6 @@ use warnings 'all';
 use Test::Simple tests => $::tests;
 use IPC::Open3;
 
-system 'env >/run/shm/env; p -3i > /run/shm/p';
 my $windows = $^O =~ /^MSWin/;
 
 sub slurp($) {
@@ -53,7 +52,6 @@ sub pl(@) {
     my $name = join ' ', 'pl', map /[\s*?()[\]{}\$\\'";|&]|^$/ ? "'$_'" : $_, @_;
     if( $windows ) {
 	require Win32::ShellQuote;
-	$cmd[2] = '..\pl';
 	@cmd = $name = Win32::ShellQuote::quote_native( @cmd );
     }
     my $none = '';
